package com.huiju.welcome.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaFirstUsherRecord;
import com.huiju.welcome.service.ITaFirstUsherRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-06-04
 */
@RestController
@RequestMapping("/")
public class TaFirstUsherRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaFirstUsherRecordController.class);

    @Autowired
    public ITaFirstUsherRecordService iTaFirstUsherRecordService;


    /**
     * 保存对象
     * @param taFirstUsherRecord 实体对象
     * @return
     */
    @RequestMapping(value="/firstUsherRecord",method= RequestMethod.POST)
    public ResponseBean save(@RequestBody TaFirstUsherRecord taFirstUsherRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaFirstUsherRecordService.save(taFirstUsherRecord)){
                responseBean.addSuccess(taFirstUsherRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taFirstUsherRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/firstUsherRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean delete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaFirstUsherRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taFirstUsherRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taFirstUsherRecord 实体对象
     * @return
     */
    @RequestMapping(value="/firstUsherRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean update(@RequestBody TaFirstUsherRecord taFirstUsherRecord, @PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaFirstUsherRecordService.updateById(taFirstUsherRecord)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taFirstUsherRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/firstUsherRecord/{id}",method= RequestMethod.GET)
    public ResponseBean get(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaFirstUsherRecordService.getById(id));
        }catch (Exception e){
            logger.error("taFirstUsherRecordGetByID -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/firstUsherRecord",method= RequestMethod.GET)
    public ResponseBean list(
        @RequestParam(defaultValue = "1") int pageNumber,
        @RequestParam(defaultValue = "10") int pageSize
    ){
        ResponseBean responseBean = new ResponseBean();
        try {
            IPage<TaFirstUsherRecord> pg = new Page<>(pageNumber, pageSize);
            QueryWrapper<TaFirstUsherRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaFirstUsherRecord> result = iTaFirstUsherRecordService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("taFirstUsherRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
