package com.huiju.welcome.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaMainUsherRecord;
import com.huiju.welcome.service.ITaMainUsherRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-06-04
 */
@RestController
@RequestMapping("/")
public class TaMainUsherRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMainUsherRecordController.class);

    @Autowired
    public ITaMainUsherRecordService iTaMainUsherRecordService;


    /**
     * 保存对象
     * @param taMainUsherRecord 实体对象
     * @return
     */
    @RequestMapping(value="/mainUsherRecord",method= RequestMethod.POST)
    public ResponseBean save(@RequestBody TaMainUsherRecord taMainUsherRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaMainUsherRecordService.save(taMainUsherRecord)){
                responseBean.addSuccess(taMainUsherRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taMainUsherRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/mainUsherRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean delete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaMainUsherRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taMainUsherRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taMainUsherRecord 实体对象
     * @return
     */
    @RequestMapping(value="/mainUsherRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean update(@RequestBody TaMainUsherRecord taMainUsherRecord, @PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaMainUsherRecordService.updateById(taMainUsherRecord)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taMainUsherRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mainUsherRecord/{id}",method= RequestMethod.GET)
    public ResponseBean get(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaMainUsherRecordService.getById(id));
        }catch (Exception e){
            logger.error("taMainUsherRecordGetByID -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 分页查询
     */
    @RequestMapping(value="/mainUsherRecord",method= RequestMethod.GET)
    public ResponseBean list(
        @RequestParam(defaultValue = "1") int pageNumber,
        @RequestParam(defaultValue = "10") int pageSize
    ){
        ResponseBean responseBean = new ResponseBean();
        try {
            IPage<TaMainUsherRecord> pg = new Page<>(pageNumber, pageSize);
            QueryWrapper<TaMainUsherRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaMainUsherRecord> result = iTaMainUsherRecordService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("taMainUsherRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
