package com.huiju.welcome.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaVisitorAppointment;
import com.huiju.welcome.service.ITaVisitorAppointmentService;
import com.huiju.welcome.utils.DateUtils;
import com.huiju.welcome.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.apache.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.Date;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-12
 */
@RestController
@RequestMapping("/")
public class TaVisitorAppointmentController extends BaseController {
    @Autowired
    ITaVisitorAppointmentService taVisitorAppointmentService;

    @GetMapping("/appointment")
    public ResponseBean list(
            @RequestParam(defaultValue = "1") Integer page,
            @RequestParam(defaultValue = "10") Integer size,
            String name,
            String phone,
            String platNumber
    ) {
        IPage<TaVisitorAppointment> pg = new Page<>(page, size);
        QueryWrapper<TaVisitorAppointment> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "person_name", name);
        queryWrapper.like(!StringUtils.isEmpty(phone), "phone", phone);
        queryWrapper.like(!StringUtils.isEmpty(platNumber), "plat_number", platNumber);
        queryWrapper.orderByDesc("create_date");

        IPage<TaVisitorAppointment> result = taVisitorAppointmentService.page(pg, queryWrapper);

        ResponseBean resp = new ResponseBean();
        resp.addSuccess(result);
        return resp;
    }

    @GetMapping("/appointment/{id}")
    public ResponseBean getByID(@PathVariable Integer id) {
        TaVisitorAppointment taVisitorAppointment = taVisitorAppointmentService.getById(id);
        return ResponseBean.success(taVisitorAppointment);
    }

    @PostMapping("/appointment")
    public ResponseBean save(@RequestBody String paramStr) {
        if (StringUtils.isEmpty(paramStr)) {
            return ResponseBean.error("请设置保存内容", HttpStatus.SC_BAD_REQUEST);
        }

        JSONObject params = JSONObject.parseObject(paramStr);
        TaVisitorAppointment taVisitorAppointment = new TaVisitorAppointment();
        taVisitorAppointment.setPersonId(params.getInteger("personId"));
        taVisitorAppointment.setPersonName(params.getString("personName"));
        taVisitorAppointment.setPhone(params.getString("phone"));
        taVisitorAppointment.setPersonNum(params.getInteger("personNum"));
        taVisitorAppointment.setCarNum(params.getInteger("carNum"));
        taVisitorAppointment.setCarModel(params.getString("carModel"));
        taVisitorAppointment.setPlatNumber(params.getString("platNumber"));
//        taVisitorAppointment.setStatus(params.getInteger("status"));

        Date dt = params.getDate("visitDate");
        if (null != dt) {
            taVisitorAppointment.setVisitDate(DateUtils.date2LocalDateTime(dt));
        }

        taVisitorAppointment.setCreateDate(LocalDateTime.now());
        boolean success = taVisitorAppointmentService.save(taVisitorAppointment);
        if (success) {
            return ResponseBean.success(taVisitorAppointment);
        } else {
            return ResponseBean.error("保存数据失败", HttpStatus.SC_INTERNAL_SERVER_ERROR);
        }
    }

    @PutMapping("/appointment/{id}")
    public ResponseBean update(@PathVariable Integer id, @RequestBody String paramStr) {
        if (StringUtils.isEmpty(paramStr)) {
            return ResponseBean.error("请设置保存内容", HttpStatus.SC_BAD_REQUEST);
        }

        JSONObject params = JSONObject.parseObject(paramStr);
        UpdateWrapper<TaVisitorAppointment> wrapper = new UpdateWrapper<>();
        wrapper.eq("appointment_id", id);
        wrapper.set("person_id", params.getInteger("personId"));
        wrapper.set("person_name", params.getString("personName"));
        wrapper.set("phone", params.getString("phone"));
        wrapper.set("visit_date", params.getString("visitDate"));
        wrapper.set("person_num", params.getInteger("personNum"));
        wrapper.set("car_num", params.getInteger("carNum"));
        wrapper.set("car_model", params.getString("carModel"));
        wrapper.set("plat_number", params.getString("platNumber"));
        wrapper.set("status", params.getInteger("status"));

        Date dt = params.getDate("visitDate");
        if (null != dt) {
            wrapper.set("visit_date", DateUtils.date2LocalDateTime(dt));
        }

        boolean success = taVisitorAppointmentService.update(new TaVisitorAppointment(), wrapper);
        if (success) {
            return ResponseBean.success(null);
        } else {
            return ResponseBean.error("更新数据失败", HttpStatus.SC_INTERNAL_SERVER_ERROR);
        }
    }
}
